@@ -122,8 +122,7 @@ USAGE
               method, if set to 2 with the direct method, if set to 3, both
               methods will be computed and compared with each other;
 4: Run the tool by typing:
-         esmvaltool -c $CONFIG_FILE \\
-             esmvaltool/recipes/recipe_thermodyn_diagtool.yml
+         esmvaltool run esmvaltool/recipes/recipe_thermodyn_diagtool.yml
 
 OUTPUT
 
